@@ -5,7 +5,8 @@ dmzsm <- function(x, J, theta, log = FALSE){
 	sn <- mzsm(y=x, J = J, theta = theta)
 	mu <- mzsm(y=1:J, J = J, theta = theta)
 	lpn <- suppressWarnings(log(sn) - log(sum(mu))) # Might be NaN if x > 0, but end result will be zero
-        lpn[ x <= 0 | x > J ] <- -Inf
+	if (any(!is.wholenumber(x))) warning("non integer values in x")
+    lpn[ x <= 0 | x > J | !is.wholenumber(x) ] <- -Inf
 	if (any(is.nan(lpn))) warning ("NaNs produced")
 	if(log) return(lpn)
 	else return(exp(lpn))
